@@ -289,19 +289,6 @@ class KamereonVehicleChargeModeData(KamereonVehicleDataAttributes):
 
     chargeMode: Optional[str]  # noqa: N815
 
-    def get_charge_mode(self) -> Optional[enums.ChargeMode]:
-        """Return charge mode."""
-        try:
-            return (
-                enums.ChargeMode(self.chargeMode)
-                if self.chargeMode is not None
-                else None
-            )
-        except ValueError:  # pragma: no cover
-            raise exceptions.KamereonException(
-                f"Unable to convert `{self.chargeMode}` to ChargeMode."
-            )
-
 
 @dataclass
 class KamereonVehicleCockpitData(KamereonVehicleDataAttributes):
@@ -331,6 +318,17 @@ class ChargeDaySchedule(BaseModel):
             "duration": self.duration,
         }
 
+    def get_end_time(self) -> Optional[str]:
+        """Create dict for json."""
+        if self.startTime is None:  # pragma: no cover
+            return None
+        start_hours = int(self.startTime[1:3])
+        start_minutes = int(self.startTime[4:6])
+        total_minutes = start_hours * 60 + start_minutes + (self.duration or 0)
+        end_hours, end_minutes = divmod(total_minutes, 60)
+        end_hours = end_hours % 24
+        return f"T{end_hours:02g}:{end_minutes:02g}Z"
+
 
 @dataclass
 class ChargeSchedule(BaseModel):
@@ -348,17 +346,59 @@ class ChargeSchedule(BaseModel):
 
     def for_json(self) -> Dict[str, Any]:
         """Create dict for json."""
-        return {
+        result: Dict[str, Any] = {
             "id": self.id,
             "activated": self.activated,
-            "monday": self.monday.for_json() if self.monday else {},
-            "tuesday": self.tuesday.for_json() if self.tuesday else {},
-            "wednesday": self.wednesday.for_json() if self.wednesday else {},
-            "thursday": self.thursday.for_json() if self.thursday else {},
-            "friday": self.friday.for_json() if self.friday else {},
-            "saturday": self.saturday.for_json() if self.saturday else {},
-            "sunday": self.sunday.for_json() if self.sunday else {},
         }
+        for day in helpers.DAYS_OF_WEEK:
+            day_spec: Optional[ChargeDaySchedule] = getattr(self, day, None)
+            if day_spec is None:
+                result[day] = day_spec
+            else:
+                result[day] = day_spec.for_json()
+        return result
+
+
+@dataclass
+class HvacDaySchedule(BaseModel):
+    """Kamereon vehicle hvac schedule for day."""
+
+    readyAtTime: Optional[str]  # noqa: N815
+
+    def for_json(self) -> Dict[str, Optional[str]]:
+        """Create dict for json."""
+        return {
+            "readyAtTime": self.readyAtTime,
+        }
+
+
+@dataclass
+class HvacSchedule(BaseModel):
+    """Kamereon vehicle hvac schedule for week."""
+
+    id: Optional[int]
+    activated: Optional[bool]
+    monday: Optional[HvacDaySchedule]
+    tuesday: Optional[HvacDaySchedule]
+    wednesday: Optional[HvacDaySchedule]
+    thursday: Optional[HvacDaySchedule]
+    friday: Optional[HvacDaySchedule]
+    saturday: Optional[HvacDaySchedule]
+    sunday: Optional[HvacDaySchedule]
+
+    def for_json(self) -> Dict[str, Any]:
+        """Create dict for json."""
+        result: Dict[str, Any] = {
+            "id": self.id,
+            "activated": self.activated,
+        }
+        for day in helpers.DAYS_OF_WEEK:
+            day_spec: Optional[HvacDaySchedule] = getattr(self, day, None)
+            if day_spec is None:
+                result[day] = day_spec
+            else:
+                result[day] = day_spec.for_json()
+        return result
 
 
 @dataclass
@@ -381,6 +421,14 @@ class KamereonVehicleChargingSettingsData(KamereonVehicleDataAttributes):
         self.schedules.append(helpers.create_schedule(args))  # pragma: no cover
 
 
+@dataclass
+class KamereonVehicleHvacSettingsData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle data hvac-settings (mode+schedules) attributes."""
+
+    mode: Optional[str]
+    schedules: Optional[List[HvacSchedule]]
+
+
 @dataclass
 class KamereonVehicleNotificationSettingsData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data notification-settings attributes."""
@@ -411,6 +459,11 @@ class KamereonVehicleHvacStartActionData(KamereonVehicleDataAttributes):
     """Kamereon vehicle action data hvac-start attributes."""
 
 
+@dataclass
+class KamereonVehicleHvacScheduleActionData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle action data hvac-schedule attributes."""
+
+
 @dataclass
 class KamereonVehicleChargeScheduleActionData(KamereonVehicleDataAttributes):
     """Kamereon vehicle action data charge-schedule attributes."""
@@ -421,6 +474,11 @@ class KamereonVehicleChargeModeActionData(KamereonVehicleDataAttributes):
     """Kamereon vehicle action data charge-mode attributes."""
 
 
+@dataclass
+class KamereonVehicleHvacModeActionData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle action data hvac-mode attributes."""
+
+
 @dataclass
 class KamereonVehicleChargingStartActionData(KamereonVehicleDataAttributes):
     """Kamereon vehicle action data charging-start attributes."""
