@@ -11,7 +11,6 @@ import aiohttp
 
 from .credential_store import CredentialStore
 from .exceptions import RenaultException
-from .kamereon import enums
 from .kamereon import models
 from .kamereon import schemas
 from .renault_session import RenaultSession
@@ -112,6 +111,18 @@ class RenaultVehicle:
             response.get_attributes(schemas.KamereonVehicleHvacStatusDataSchema),
         )
 
+    async def get_hvac_settings(self) -> models.KamereonVehicleHvacSettingsData:
+        """Get vehicle hvac settings (schedule+mode)."""
+        response = await self.session.get_vehicle_data(
+            account_id=self.account_id,
+            vin=self.vin,
+            endpoint="hvac-settings",
+        )
+        return cast(
+            models.KamereonVehicleHvacSettingsData,
+            response.get_attributes(schemas.KamereonVehicleHvacSettingsDataSchema),
+        )
+
     async def get_charge_mode(self) -> models.KamereonVehicleChargeModeData:
         """Get vehicle charge mode."""
         response = await self.session.get_vehicle_data(
@@ -177,7 +188,7 @@ class RenaultVehicle:
         )
 
     async def get_charge_history(
-        self, start: datetime, end: datetime, period: str = "month"
+        self, start: datetime, end: datetime, period: str
     ) -> models.KamereonVehicleChargeHistoryData:
         """Get vehicle charge history."""
         if not isinstance(start, datetime):  # pragma: no cover
@@ -244,7 +255,7 @@ class RenaultVehicle:
         )
 
     async def get_hvac_history(
-        self, start: datetime, end: datetime, period: str = "month"
+        self, start: datetime, end: datetime, period: str
     ) -> models.KamereonVehicleHvacHistoryData:
         """Get vehicle hvac history."""
         if not isinstance(start, datetime):  # pragma: no cover
@@ -355,6 +366,32 @@ class RenaultVehicle:
             response.get_attributes(schemas.KamereonVehicleHvacStartActionDataSchema),
         )
 
+    async def set_hvac_schedules(
+        self, schedules: List[models.HvacSchedule]
+    ) -> models.KamereonVehicleHvacScheduleActionData:
+        """Set vehicle charge schedules."""
+        for schedule in schedules:
+            if not isinstance(schedule, models.HvacSchedule):  # pragma: no cover
+                raise TypeError(
+                    "`schedules` should be a list of HvacSchedule, not {}".format(
+                        schedules.__class__
+                    )
+                )
+        attributes = {"schedules": list(schedule.for_json() for schedule in schedules)}
+
+        response = await self.session.set_vehicle_action(
+            account_id=self.account_id,
+            vin=self.vin,
+            endpoint="hvac-schedule",
+            attributes=attributes,
+        )
+        return cast(
+            models.KamereonVehicleHvacScheduleActionData,
+            response.get_attributes(
+                schemas.KamereonVehicleHvacScheduleActionDataSchema
+            ),
+        )
+
     async def set_charge_schedules(
         self, schedules: List[models.ChargeSchedule]
     ) -> models.KamereonVehicleChargeScheduleActionData:
@@ -382,16 +419,10 @@ class RenaultVehicle:
         )
 
     async def set_charge_mode(
-        self, charge_mode: enums.ChargeMode
+        self, charge_mode: str
     ) -> models.KamereonVehicleChargeModeActionData:
         """Set vehicle charge mode."""
-        if not isinstance(charge_mode, enums.ChargeMode):  # pragma: no cover
-            raise TypeError(
-                "`charge_mode` should be an instance of ChargeMode, not {}".format(
-                    charge_mode.__class__
-                )
-            )
-        attributes = {"action": charge_mode.value}
+        attributes = {"action": charge_mode}
 
         response = await self.session.set_vehicle_action(
             account_id=self.account_id,
